@@ -2,6 +2,9 @@ import gconf
 import gobject
 
 class GconfStore(gobject.GObject):
+    """
+    Handles storing to and retrieving values from GConf 
+    """
 
     # GConf directory for deskbar in window mode and shared settings
     GCONF_DIR = "/apps/deskbar"
@@ -28,14 +31,9 @@ class GconfStore(gobject.GObject):
     # GConf key for collapsed categories in the cuemiac view
     GCONF_COLLAPSED_CAT = GCONF_DIR + "/collapsed_cat"
     
-    GCONF_SHOW_HISTORY = GCONF_DIR + "/show_history"
-    
     GCONF_WINDOW_WIDTH = GCONF_DIR + "/window_width"
     GCONF_WINDOW_HEIGHT = GCONF_DIR + "/window_height"
     
-    GCONF_WINDOW_X = GCONF_DIR + "/window_x"
-    GCONF_WINDOW_Y = GCONF_DIR + "/window_y"
-    
     GCONF_HIDE_AFTER_ACTION = GCONF_DIR + "/hide_after_action"
     
     GCONF_MAX_HISTORY_ITEMS = GCONF_DIR + "/max_history_items"
@@ -51,7 +49,6 @@ class GconfStore(gobject.GObject):
         "proxy-port-changed" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_STRING]),
         "enabled-modules-changed" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_PYOBJECT]),
         "collapsed-rows-changed" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_PYOBJECT]),
-        "show-history-changed" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_BOOLEAN]),
         "hide-after-action-changed" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_BOOLEAN]),
         "max-history-items-changed" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [gobject.TYPE_INT]),
     }
@@ -65,6 +62,9 @@ class GconfStore(gobject.GObject):
         return GconfStore.__instance
         
     def __init__(self):
+        """
+        *Do not* use the constructor directly. Always use L{get_instance}
+        """
         super(GconfStore, self).__init__()
         self._client = gconf.client_get_default()
         self.__connect_notifications()
@@ -81,7 +81,6 @@ class GconfStore(gobject.GObject):
         self._client.notify_add(self.GCONF_PROXY_PORT_KEY, lambda x, y, z, a: self.emit("proxy-port-changed", z.value.get_string()))
         self._client.notify_add(self.GCONF_ENABLED_HANDLERS, lambda x, y, z, a: self.emit("enabled-modules-changed", [i.get_string() for i in z.value.get_list()]))
         self._client.notify_add(self.GCONF_COLLAPSED_CAT, lambda x, y, z, a: self.emit("collapsed-rows-changed", [i.get_string() for i in z.value.get_list()]))
-        self._client.notify_add(self.GCONF_SHOW_HISTORY, lambda x, y, z, a: self.emit("show-history-changed", z.value.get_bool()))
         self._client.notify_add(self.GCONF_HIDE_AFTER_ACTION, lambda x, y, z, a: self.emit("hide-after-action-changed", z.value.get_bool()))
         self._client.notify_add(self.GCONF_TYPINGDELAY, lambda x, y, z, a: self.emit("max-history-items-changed", z.value.get_int()))
     
@@ -133,20 +132,11 @@ class GconfStore(gobject.GObject):
     def get_collapsed_cat(self):
         return self._client.get_list(self.GCONF_COLLAPSED_CAT, gconf.VALUE_STRING)
     
-    def get_show_history(self):
-        return self._client.get_bool(self.GCONF_SHOW_HISTORY)
-    
     def get_window_width(self):
         return self._client.get_int(self.GCONF_WINDOW_WIDTH)
     
     def get_window_height(self):
         return self._client.get_int(self.GCONF_WINDOW_HEIGHT)
-    
-    def get_window_x(self):
-        return self._client.get_int(self.GCONF_WINDOW_X)
-        
-    def get_window_y(self):
-        return self._client.get_int(self.GCONF_WINDOW_Y)
    
     def get_hide_after_action(self):
         return self._client.get_bool(self.GCONF_HIDE_AFTER_ACTION)
@@ -183,22 +173,13 @@ class GconfStore(gobject.GObject):
         
     def set_collapsed_cat(self, cat):
         self._client.set_list(self.GCONF_COLLAPSED_CAT, gconf.VALUE_STRING, cat)
-        
-    def set_show_history(self, val):
-        self._client.set_bool(self.GCONF_SHOW_HISTORY, val)
-    
+     
     def set_window_width(self, width):
         self._client.set_int(self.GCONF_WINDOW_WIDTH, width)
     
     def set_window_height(self, height):
         self._client.set_int(self.GCONF_WINDOW_HEIGHT, height)  
     
-    def set_window_x(self, x):
-        self._client.set_int(self.GCONF_WINDOW_X, x)
-        
-    def set_window_y(self, y):
-        self._client.set_int(self.GCONF_WINDOW_Y, y)
-    
     def set_hide_after_action(self, val):
         self._client.set_bool(self.GCONF_HIDE_AFTER_ACTION, val)
         
